@@ -40,6 +40,103 @@ class NagVisMapObj extends NagVisStatefulObject {
     protected $linkedMaps;
 
     protected $map_name;
+    protected $alias;
+
+    // globals of a map are loaded into the NagVisMapObj
+    protected $sources;
+    protected $parent_map;
+    protected $in_maintenance;
+    protected $show_in_lists;
+    protected $show_in_multisite;
+    protected $ignore_linked_maps_summary_state;
+    protected $map_image;
+    protected $background_color;
+    protected $grid_show;
+    protected $grid_color;
+    protected $grid_steps;
+    protected $header_menu;
+    protected $header_template;
+    protected $header_fade;
+    protected $stylesheet;
+    protected $zoom;
+    protected $zoombar;
+    protected $backend_id;
+    protected $context_menu;
+    protected $context_template;
+    protected $exclude_members;
+    protected $exclude_member_states;
+    protected $hover_menu;
+    protected $hover_delay;
+    protected $hover_template;
+    protected $hover_childs_show;
+    protected $hover_childs_limit;
+    protected $hover_childs_order;
+    protected $hover_childs_sort;
+    protected $line_color;
+    protected $host_url;
+    protected $hostgroup_url;
+    protected $service_url;
+    protected $servicegroup_url;
+    protected $map_url;
+    protected $dyngroup_url;
+    protected $aggr_url;
+    protected $event_on_load;
+    protected $event_repeat_interval;
+    protected $event_repeat_duration;
+    protected $event_background;
+    protected $event_highlight;
+    protected $event_highlight_interval;
+    protected $event_highlight_duration;
+    protected $event_log;
+    protected $event_log_level;
+    protected $event_log_events;
+    protected $event_log_height;
+    protected $event_log_hidden;
+    protected $event_scroll;
+    protected $event_sound;
+    protected $default_params;
+
+    // Worldmap source
+    protected $worldmap_center;
+    protected $worldmap_zoom;
+    protected $worldmap_tiles_saturate;
+
+    // Automap source
+    protected $render_mode;
+    protected $root;
+    protected $filter_by_state;
+    protected $filter_by_ids;
+    protected $child_layers;
+    protected $parent_layers;
+    protected $ignore_hosts;
+    protected $margin;
+    protected $rankdir;
+    protected $overlap;
+
+    // Geomap source
+    protected $geomap_type;
+    protected $geomap_zoom;
+    protected $source_type;
+    protected $source_file;
+    protected $geomap_border;
+
+    // General source
+    protected $width;
+    protected $height;
+
+    // Filter source
+    protected $filter_group;
+
+    // Dynmap source
+    protected $dynmap_object_types;
+    protected $dynmap_object_filter;
+    protected $dynmap_init_x;
+    protected $dynmap_init_y;
+    protected $dynmap_offset_x;
+    protected $dynmap_offset_y;
+    protected $dynmap_per_row;
+    protected $dynmap_sort;
+    protected $dynmap_order;
 
     // When this map object summarizes the state of a map this is true
     // Prevents loops
