@@ -30,5 +30,9 @@ class NagVisStatelessObject extends NagVisObject {
 
     protected static $iconPath      = null;
     protected static $iconPathLocal = null;
+
+    public function getName() {
+        return $this->object_id;
+    }
 }
 ?>
